# afmaths

A simple package of math functions. Many of these will display output to the console to help understand what steps are required.

# Modules

- afmaths
  - add(), subtract(), multiply(), divide(), exponentiate(), square_root(), factorial(), euclid()
- cs
  - cs_file_compression_ratio(), cs_compressed_file_size(), cs_diagonal_pixel_length(), cs_travelling_salesman_problem_total_routes(), cs_check_clusters(), cs_ml_precision(), cs_ml_recall(), cs_ml_weighted_inputs()
- graphs
  - graph_gradient(), graph_equation_of_line()
- lists
  - list_sorted(), list_length(), list_sum(), list_minimum(), list_maximum(), list_range(), list_mean(), list_median(), list_quartiles()
- physics
  - physics_radiowave_power_distances(), physics_radiowave_recieved_power(), physics_speed_of_light_metres_per_second(), physics_planck_constant(), physics_photon_energy_from_wavelength(), physics_photon_energy_from_frequency(), physics_frequency_to_wavelength(), physics_wavelength_to_frequency()
